#define MAX_INPUT_SIZE (1 << 24)

extern u8 input_buf[MAX_INPUT_SIZE];
extern u8 output_buf[MAX_INPUT_SIZE + 3];
extern unsigned int input_len, output_len, out_bitpos;

void crunch(void);
